# Contribute to balder

Every contribution to balder or to the BalderHub projects are highly appreciated. A simple typo, a documentation 
improvement, a bug-fix or the implementation of new features - everything counts.

Are you an expert in your field? Do you enjoy the concept of balder? How about you create your own
BalderHub project? Take a look into our [Balder GitHub Group](https://github.com/balder-dev) and feel free to share 
your ideas. You can contribute to an existing project or create your own. If you are not sure, a BalderHub project for 
an idea already exists or if you want to discuss your ideas with others, feel free to
[create an issue in the BalderHub main entry project](https://github.com/balder-dev/hub.balder.dev/issues) or
[start a new discussion](https://github.com/balder-dev/hub.balder.dev/discussions).

## If you like it - share it

Any mention of Balder on twitter or another social media platform is highly appreciated. The more people know about 
Balder, the more efficient this project can become. If you want to support people in their Balder journey, you can start
by posting on a blog.

## Feature suggestion 

Do you have a new idea for balder or do you have a suggestion for a feature? You can start a 
[discussion on GitHub](https://github.com/balder-dev/balder/discussions) or feel free to 
[submit it as an issue](https://github.com/balder-dev/balder/issues). 

## BalderHub suggestion/integration

Do you have a new idea for a BalderHub project? Currently, we are developing a global BalderHub webpage, which will 
be used as the main entrance for all BalderHub projects. 

To ensure that no other similar projects will be developed, you can port your BalderHub project to our ``balder-dev`` 
GitHub group and integrate it into the ``balder.dev`` domain. Of course, you get maintainer access to your project and
still be the main developer. Simply create an issue in the 
[BalderHub entry project](https://github.com/balder-dev/hub.balder.dev), and we will trigger the 
porting as soon as possible.

Please name your BalderHub project ``balderhub-*`` in pypi.
If you port your BalderHub project to the main developer group, your documentation will be provided on 
``https://hub.balder.dev/your-balderhub-name`` soon.

## BalderPlugin suggestion/integration

You can also create your own balder-plugin. If you want to add it to the main documentation website, you can 
[create a new issue in the main plugin project](), and we will organize the project porting to the ``balder-dev`` 
group.

Please name your balder-plugin project ``balderplugin-*`` in pypi.

If you port your balder-plugin project to the main developer group, your documentation will be provided on 
``https://plugins.balder.dev/your-balder-plugin-name``.

## Pull-Request Review process

Currently, I (@matosys) am the only active developer. If you like, I will gladly give you commit access once you have 
contributed a couple of pull requests. Once we are three active members, I'd suggest using a 
pull-request-and-review process. Until then, I will review every pull request as soon as possible. 
I will gladly make an effort to answer every question, suggestion, bug-fix and pull-request.

## Add new test

Every contribution is welcome! We can never have enough tests. You can also take a look 
in the [issue list with the tag ``test``](https://github.com/balder-dev/balder/issues).

You can find more information about how tests can be created for the balder-core at [test README](tests/README.md).